@@ -2,11 +2,15 @@ var IConnection_8h =
 [
     [ "sdbus::IConnection", "classsdbus_1_1IConnection.html", "classsdbus_1_1IConnection" ],
     [ "sdbus::IConnection::PollData", "structsdbus_1_1IConnection_1_1PollData.html", "structsdbus_1_1IConnection_1_1PollData" ],
+    [ "createBusConnection", "IConnection_8h.html#a4ddb605a6f4040fa95dbaf48c4e83f4b", null ],
     [ "createConnection", "IConnection_8h.html#af97a3568a21aba8df3a0c05a9d3b2f34", null ],
     [ "createConnection", "IConnection_8h.html#ace7f66e6c46d6fe02e800a7f3f2e2901", null ],
     [ "createDefaultBusConnection", "IConnection_8h.html#a324a57f39501ac6e4dd0f21211f62add", null ],
     [ "createDefaultBusConnection", "IConnection_8h.html#a3426ed2a74515a0e355444b7b129424d", null ],
+    [ "createDirectBusConnection", "IConnection_8h.html#aa48c1746501c163547344b2a9f57673c", null ],
+    [ "createDirectBusConnection", "IConnection_8h.html#a5c0a6e52e132a1d8984cb64e06906162", null ],
     [ "createRemoteSystemBusConnection", "IConnection_8h.html#a803551c47da11b5d137c2b7132453828", null ],
+    [ "createServerBus", "IConnection_8h.html#ac1b366259d5cb3b29de728b5f3d960a8", null ],
     [ "createSessionBusConnection", "IConnection_8h.html#a0b7b34085806849eca7151684834734a", null ],
     [ "createSessionBusConnection", "IConnection_8h.html#a16396a6e7775b4e15af05d71e38627ec", null ],
     [ "createSessionBusConnectionWithAddress", "IConnection_8h.html#a2bb69db85ee48bdaa3419b09a254ed7a", null ],
